diff Plugins/Input/wav/wav-sndfile.c @ 1459:705d4c089fce trunk

[svn] Fix postal code.
author chainsaw
date Wed, 02 Aug 2006 16:00:13 -0700
parents f12d7e208b43
children
line wrap: on
line diff
--- a/Plugins/Input/wav/wav-sndfile.c	Wed Aug 02 15:44:07 2006 -0700
+++ b/Plugins/Input/wav/wav-sndfile.c	Wed Aug 02 16:00:13 2006 -0700
@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
  */
 
 #include <glib.h>
@@ -259,7 +259,7 @@
 			  "License along with this program ; if not, write to \n"
 			  "the Free Software Foundation, Inc., \n"
 			  "51 Franklin Street, Fifth Floor, \n"
-			  "Boston, MA  02111-1307  USA"),
+			  "Boston, MA  02110-1301  USA"),
 			_("Ok"), FALSE, NULL, NULL);
 		g_signal_connect(G_OBJECT(box), "destroy",
 			(GCallback)gtk_widget_destroyed, &box);
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 